/*
 * test
 *
 * Copyright (c) 2013 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include "test.h"

#define METHOD_TIME_SET_DATETIME	"set_datetime"
#define METHOD_TIME_SET_TIMEZONE	"set_timezone"

static bool request_sysnoti_method(const char *method, GVariant *param)
{
	GVariant *msg;
	int val;
	bool ret = FALSE;

	msg = dbus_handle_method_sync_with_reply_var(DEVICED_BUS_NAME,
						DEVICED_PATH_SYSNOTI,
						DEVICED_INTERFACE_SYSNOTI,
						method,
						param);
	if (!msg) {
		_E("fail (%s): no reply", method);
		return ret;
	}

	if (!dh_get_param_from_var(msg, "(i)", &val))
		_E("fail (%s): no message", method);
	else {
		if ((val == -ENOTSUP) || (val == -ENOSYS)) {
			_I("Not supported feature! (%s): %d", method, val);
			ret = TRUE;
		} else if (val < 0) {
			_E("fail (%s): returned fail (%d)", method, val);
		} else {
			_I("success (%s): %d", method, val);
			ret = TRUE;
		}
	}

	g_variant_unref(msg);
	return ret;
}

static bool set_time_datetime(int date_time)
{
	char str_time[10];
	snprintf(str_time, sizeof(str_time) - 1, "%d", date_time);
	return request_sysnoti_method(METHOD_TIME_SET_DATETIME, g_variant_new("(sis)", METHOD_TIME_SET_DATETIME, 1, str_time));
}

static bool set_time_timezone(char *localtime_path)
{
	return request_sysnoti_method(METHOD_TIME_SET_TIMEZONE, g_variant_new("(sis)", METHOD_TIME_SET_TIMEZONE, 1, localtime_path));
}

void time_test_all(int *success, int *fail)
{
	int s = 0;
	int f = 0;

	(set_time_datetime(time(NULL)-600))		? s++ : f++;
	(set_time_datetime(time(NULL)))			? s++ : f++;
	(set_time_timezone("/usr/share/zoneinfo/America/Cancun"))	? s++ : f++;
	(set_time_timezone("/usr/share/zoneinfo/Asia/Seoul"))		? s++ : f++;

	if (NULL != success)    *success = s;
	if (NULL != fail)       *fail = f;
}

static void time_init(void *data)
{
	int success = 0;
	int fail = 0;

	_I("start test");

	time_test_all(&success, &fail);

	_I("Total: %d, Success: %d, Fail: %d", success+fail, success, fail);
}

static void time_exit(void *data)
{
	_I("end test");
}

static int time_unit(int argc, char **argv)
{
	if (argc < 4) {
		int success = 0;
		int fail = 0;

		_I("start test");
		time_test_all(&success, &fail);
		_I("Total: %d, Success: %d, Fail: %d", success+fail, success, fail);
	} else if (0 == strcasecmp(argv[3], METHOD_TIME_SET_DATETIME)) {
		set_time_datetime(atoi(argv[4]));
	} else if (0 == strcasecmp(argv[3], METHOD_TIME_SET_TIMEZONE)) {
		set_time_timezone(argv[4]);
	} else {
		_E("Unknown test case!!!");
	}

	return 0;
}

static const struct test_ops time_test_ops = {
	.priority = TEST_PRIORITY_NORMAL,
	.name     = "time",
	.init     = time_init,
	.exit    = time_exit,
	.unit    = time_unit,
};

TEST_OPS_REGISTER(&time_test_ops)
